OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "Календар",
    "Deck" : "Deck",
    "Files" : "Датотеки",
    "Talk conversation" : "Talk раговор",
    "Talk" : "Разговор"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
